SchemaSpy - Table gnss_data.public.stations

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.stations | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
NetworkCode | varchar | 3 |  |  |  |
apr_coords.NetworkCode | apr_coords_NetworkCode_fkey R
gamit_soln.NetworkCode | gamit_soln_NetworkCode_fkey R
locks.NetworkCode | locks_NetworkCode_fkey C
ppp_soln.NetworkCode | ppp_soln_NetworkName_StationCode_fkey R
ppp_soln_excl.NetworkCode | ppp_soln_excl_NetworkCode_fkey R
rinex.NetworkCode | rinex_NetworkCode_fkey R
rinex_extra.NetworkCode | rinex_extra_NetworkCode_fkey R
stationinfo.NetworkCode | stationinfo_NetworkCode_StationCode_fkey R
networks.NetworkCode | NetworkCode R
StationCode | varchar | 4 |  |  |  |
apr_coords.StationCode | apr_coords_NetworkCode_fkey R
gamit_soln.StationCode | gamit_soln_NetworkCode_fkey R
locks.StationCode | locks_NetworkCode_fkey C
ppp_soln.StationCode | ppp_soln_NetworkName_StationCode_fkey R
ppp_soln_excl.StationCode | ppp_soln_excl_NetworkCode_fkey R
rinex.StationCode | rinex_NetworkCode_fkey R
rinex_extra.StationCode | rinex_extra_NetworkCode_fkey R
stationinfo.StationCode | stationinfo_NetworkCode_StationCode_fkey R
StationName | varchar | 40 | √ |  | null |  |  |
DateStart | numeric | 7,3 | √ |  | null |  |  |
DateEnd | numeric | 7,3 | √ |  | null |  |  |
auto_x | numeric | 131089 | √ |  | null |  |  |
auto_y | numeric | 131089 | √ |  | null |  |  |
auto_z | numeric | 131089 | √ |  | null |  |  |
Harpos_coeff_otl | text | 2147483647 | √ |  | null |  |  |
lat | numeric | 131089 | √ |  | null |  |  |
lon | numeric | 131089 | √ |  | null |  |  |
height | numeric | 131089 | √ |  | null |  |  |
Table contained 350 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: